Module bridge

Module bridge 

Structs

LuaTool
A Tool implementation backed by a Lua function registered with imp.register_tool().

Functions

json_to_lua_value
Convert a serde_json::Value to a Lua value.
load_lua_tools
Register all currently loaded Lua tools with imp-core’s tool registry.
lua_value_to_json
Convert a Lua value to serde_json::Value.
setup_host_api
Set up the imp global table with host API functions.