Re-exports
pub use bridge::json_to_lua_value;pub use bridge::load_lua_tools;pub use bridge::lua_value_to_json;pub use bridge::setup_host_api;pub use bridge::LuaTool;pub use loader::discover_extensions;pub use loader::load_extensions;pub use loader::reload;pub use loader::LuaExtension;pub use sandbox::LuaCallContext;pub use sandbox::LuaCommandHandle;pub use sandbox::LuaError;pub use sandbox::LuaHookHandle;pub use sandbox::LuaRuntime;pub use sandbox::LuaToolHandle;
Modules
Functions
- init_
lua_ extensions - Discover and load Lua extensions from user and project directories, registering any tools they define onto the given registry.